# kepi

kepi is a Django-based microblogging system, implemented in Python.
It uses the ActivityPub protocol to communicate with other servers,
and the Mastodon protocol to communicate with clients.

There is nothing particularly interesting at [kepi.org.uk](https://kepi.org.uk),
but there will be.

## Links

* [The installation guide](docs/installation.md) (may be out of date)
* [A guide to the structure](docs/modules.md)
* [The roadmap](docs/roadmap.md)
* [Source control](https://gitlab.com/marnanel/kepi)
* [The bug tracker](https://gitlab.com/marnanel/kepi/issues)
* [kepi threads on the activitypub forums](https://socialhub.activitypub.rocks/c/software/kepi/32)

## Trivia

* [bowler-heavy](docs/bowler-heavy.md) was a historical course change that may still affect the state of the codebase.
* [Why the name?](docs/name.md)
